==> kst-1.1.0_dr1.tar.gz: kst-1.1.0_dr1/kst/kst/dialoglauncher-nogui.cpp <==
/***************************************************************************
                          dialoglauncher-nogui.cpp
                             -------------------
    begin                : Nov. 24, 2004
    copyright            : (C) 2004 The University of Toronto
    email                :
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "dialoglauncher.h"

namespace KstDialogs {
  void showHistogramDialog(const QString& name) {
    Q_UNUSED(name)
  }


  void showPluginDialog(const QString& name) {
    Q_UNUSED(name)
  }


  void showEquationDialog(const QString& name) {
    Q_UNUSED(name)
  }


  void showPSDDialog(const QString& name) {
    Q_UNUSED(name)
  }


  void showMatrixDialog(const QString& name) {
    Q_UNUSED(name)
  }


  void showImageDialog(const QString& name) {
    Q_UNUSED(name)
  }


  void showCurveDialog(const QString& name) {
    Q_UNUSED(name)
  }


};

// vim: ts=2 sw=2 et

==> kst-1.2.0dr1.tar.gz: kst-1.2.0dr1/kst/kst/dialoglauncher-nogui.cpp <==
/***************************************************************************
                          dialoglauncher-nogui.cpp
                             -------------------
    begin                : Nov. 24, 2004
    copyright            : (C) 2004 The University of Toronto
    email                :
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "dialoglauncher.h"

namespace KstDialogs {
  void showHistogramDialog(const QString& name) {
    Q_UNUSED(name)
  }


  void showPluginDialog(const QString& name) {
    Q_UNUSED(name)
  }


  void showEquationDialog(const QString& name) {
    Q_UNUSED(name)
  }


  void showCSDDialog(const QString& name) {
    Q_UNUSED(name)
  }


  void showPSDDialog(const QString& name) {
    Q_UNUSED(name)
  }


  void newVectorDialog(QWidget *parent, const char *createdSlot, const char *selectedSlot, const char *updateSlot) {
    Q_UNUSED(parent)
    Q_UNUSED(createdSlot)
    Q_UNUSED(selectedSlot)
    Q_UNUSED(updateSlot)
  }


  void showVectorDialog(const QString& name) {
    Q_UNUSED(name)
  }


  void newMatrixDialog(QWidget *parent, const char *createdSlot, const char *selectedSlot, const char *updateSlot) {
    Q_UNUSED(parent)
    Q_UNUSED(createdSlot)
    Q_UNUSED(selectedSlot)
    Q_UNUSED(updateSlot)
  }


  void showMatrixDialog(const QString& name) {
    Q_UNUSED(name)
  }


  void showImageDialog(const QString& name) {
    Q_UNUSED(name)
  }


  void showCurveDialog(const QString& name) {
    Q_UNUSED(name)
  }


}

// vim: ts=2 sw=2 et
